@@ -11,8 +11,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <inttypes.h>
 #include <stdbool.h>
@@ -48,7 +46,6 @@
 #define MAX_RSA 4096 /* should be long enough... */
 
 const char *program = "dnssec-keyfromlabel";
-int verbose;
 
 ISC_PLATFORM_NORETURN_PRE static void
 usage(void) ISC_PLATFORM_NORETURN_POST;
