@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 
@@ -19,7 +17,7 @@
 #ifdef ENABLE_AFL
 #include <named/globals.h>
 #include <named/server.h>
-#include <errno.h>
+#include <sys/errno.h>
 
 #include <isc/app.h>
 #include <isc/condition.h>
