@@ -11,8 +11,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
@@ -2636,7 +2634,7 @@ recvsoa(isc_task_t *task, isc_event_t *event) {
 		 * address.
 		 */
 		zname = dns_fixedname_initname(&fzname);
-		dns_name_copynf(name, zname);
+		dns_name_copy(name, zname, NULL);
 	}
 
 	if (debugging) {
