@@ -11,8 +11,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -249,8 +247,6 @@ get_addresses(const char *host, in_port_t port) {
 	isc_result_t result;
 	int found = 0, count;
 
-	REQUIRE(host != NULL);
-
 	if (*host == '/') {
 		result = isc_sockaddr_frompath(&serveraddrs[nserveraddrs],
 					       host);
@@ -992,9 +988,8 @@ main(int argc, char **argv) {
 	if (strcmp(command, "restart") == 0)
 		fatal("'%s' is not implemented", command);
 
-	if (nserveraddrs == 0 && servername != NULL) {
+	if (nserveraddrs == 0)
 		get_addresses(servername, (in_port_t) remoteport);
-	}
 
 	DO("post event", isc_app_onrun(rndc_mctx, task, rndc_start, NULL));
 
