@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #include <stdbool.h>
 #include <stddef.h>
 
@@ -19,7 +17,6 @@
 #include <isc/mem.h>
 #include <isc/mutex.h>
 #include <isc/portset.h>
-#include <isc/refcount.h>
 #include <isc/safe.h>
 #include <isc/sockaddr.h>
 #include <isc/socket.h>
@@ -95,9 +92,8 @@ struct dns_client {
 	unsigned int			find_timeout;
 	unsigned int			find_udpretries;
 
-	isc_refcount_t			references;
-
 	/* Locked */
+	unsigned int			references;
 	dns_viewlist_t			viewlist;
 	ISC_LIST(struct resctx)		resctxs;
 	ISC_LIST(struct reqctx)		reqctxs;
@@ -504,13 +500,12 @@ dns_client_createx(isc_mem_t *mctx, isc_appctx_t *actx,
 
 	client->task = NULL;
 	result = isc_task_create(client->taskmgr, 0, &client->task);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_lock;
-	}
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 
 	result = dns_dispatchmgr_create(mctx, &dispatchmgr);
 	if (result != ISC_R_SUCCESS)
-		goto cleanup_task;
+		goto cleanup;
 	client->dispatchmgr = dispatchmgr;
 	(void)setsourceports(mctx, dispatchmgr);
 
@@ -523,9 +518,8 @@ dns_client_createx(isc_mem_t *mctx, isc_appctx_t *actx,
 		result = getudpdispatch(AF_INET, dispatchmgr, socketmgr,
 					taskmgr, true,
 					&dispatchv4, localaddr4);
-		if (result == ISC_R_SUCCESS) {
+		if (result == ISC_R_SUCCESS)
 			client->dispatchv4 = dispatchv4;
-		}
 	}
 
 	client->dispatchv6 = NULL;
@@ -533,27 +527,22 @@ dns_client_createx(isc_mem_t *mctx, isc_appctx_t *actx,
 		result = getudpdispatch(AF_INET6, dispatchmgr, socketmgr,
 					taskmgr, true,
 					&dispatchv6, localaddr6);
-		if (result == ISC_R_SUCCESS) {
+		if (result == ISC_R_SUCCESS)
 			client->dispatchv6 = dispatchv6;
-		}
 	}
 
 	/* We need at least one of the dispatchers */
 	if (dispatchv4 == NULL && dispatchv6 == NULL) {
 		INSIST(result != ISC_R_SUCCESS);
-		goto cleanup_dispatchmgr;
+		goto cleanup;
 	}
 
-	isc_refcount_init(&client->references, 1);
-
 	/* Create the default view for class IN */
 	result = createview(mctx, dns_rdataclass_in, options, taskmgr,
 			    RESOLVER_NTASKS, socketmgr, timermgr,
 			    dispatchmgr, dispatchv4, dispatchv6, &view);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_references;
-	}
-
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 	ISC_LIST_INIT(client->viewlist);
 	ISC_LIST_APPEND(client->viewlist, view, link);
 
@@ -573,38 +562,32 @@ dns_client_createx(isc_mem_t *mctx, isc_appctx_t *actx,
 	client->find_udpretries = DEF_FIND_UDPRETRIES;
 	client->attributes = 0;
 
+	client->references = 1;
 	client->magic = DNS_CLIENT_MAGIC;
 
 	*clientp = client;
 
 	return (ISC_R_SUCCESS);
 
- cleanup_references:
-	isc_refcount_decrement(&client->references);
-	isc_refcount_destroy(&client->references);
- cleanup_dispatchmgr:
-	if (dispatchv4 != NULL) {
+ cleanup:
+	if (dispatchv4 != NULL)
 		dns_dispatch_detach(&dispatchv4);
-	}
-	if (dispatchv6 != NULL) {
+	if (dispatchv6 != NULL)
 		dns_dispatch_detach(&dispatchv6);
-	}
-	dns_dispatchmgr_destroy(&dispatchmgr);
- cleanup_task:
-	isc_task_detach(&client->task);
- cleanup_lock:
-	isc_mutex_destroy(&client->lock);
+	if (dispatchmgr != NULL)
+		dns_dispatchmgr_destroy(&dispatchmgr);
+	if (client->task != NULL)
+		isc_task_detach(&client->task);
 	isc_mem_put(mctx, client, sizeof(*client));
 
 	return (result);
 }
 
 static void
-destroyclient(dns_client_t *client) {
+destroyclient(dns_client_t **clientp) {
+	dns_client_t *client = *clientp;
 	dns_view_t *view;
 
-	isc_refcount_destroy(&client->references);
-
 	while ((view = ISC_LIST_HEAD(client->viewlist)) != NULL) {
 		ISC_LIST_UNLINK(client->viewlist, view, link);
 		dns_view_detach(&view);
@@ -636,20 +619,32 @@ destroyclient(dns_client_t *client) {
 	client->magic = 0;
 
 	isc_mem_putanddetach(&client->mctx, client, sizeof(*client));
+
+	*clientp = NULL;
 }
 
 void
 dns_client_destroy(dns_client_t **clientp) {
 	dns_client_t *client;
+	bool destroyok = false;
 
 	REQUIRE(clientp != NULL);
 	client = *clientp;
-	*clientp = NULL;
 	REQUIRE(DNS_CLIENT_VALID(client));
 
-	if (isc_refcount_decrement(&client->references) == 1) {
-		destroyclient(client);
+	LOCK(&client->lock);
+	client->references--;
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs)) {
+		destroyok = true;
 	}
+	UNLOCK(&client->lock);
+
+	if (destroyok)
+		destroyclient(&client);
+
+	*clientp = NULL;
 }
 
 isc_result_t
@@ -933,12 +928,21 @@ client_resfind(resctx_t *rctx, dns_fetchevent_t *event) {
 			 * Otherwise, get some resource for copying the
 			 * result.
 			 */
-			dns_name_t *aname = dns_fixedname_name(&rctx->name);
-
 			ansname = isc_mem_get(mctx, sizeof(*ansname));
-			dns_name_init(ansname, NULL);
+			if (ansname == NULL)
+				tresult = ISC_R_NOMEMORY;
+			else {
+				dns_name_t *aname;
 
-			(void)dns_name_dup(aname, mctx, ansname);
+				aname = dns_fixedname_name(&rctx->name);
+				dns_name_init(ansname, NULL);
+				tresult = dns_name_dup(aname, mctx, ansname);
+				if (tresult != ISC_R_SUCCESS)
+					isc_mem_put(mctx, ansname,
+						    sizeof(*ansname));
+			}
+			if (tresult != ISC_R_SUCCESS)
+				result = tresult;
 		}
 
 		switch (result) {
@@ -975,9 +979,12 @@ client_resfind(resctx_t *rctx, dns_fetchevent_t *event) {
 			dns_rdata_reset(&rdata);
 			if (tresult != ISC_R_SUCCESS)
 				goto done;
-			dns_name_copynf(&cname.cname, name);
+			tresult = dns_name_copy(&cname.cname, name, NULL);
 			dns_rdata_freestruct(&cname);
-			want_restart = true;
+			if (tresult == ISC_R_SUCCESS)
+				want_restart = true;
+			else
+				result = tresult;
 			goto done;
 		case DNS_R_DNAME:
 			/*
@@ -1386,7 +1393,13 @@ dns_client_startresolve(dns_client_t *client, const dns_name_t *name,
 	ISC_LIST_INIT(event->answerlist);
 
 	rctx = isc_mem_get(mctx, sizeof(*rctx));
-	isc_mutex_init(&rctx->lock);
+	if (rctx == NULL)
+		result = ISC_R_NOMEMORY;
+	else {
+		isc_mutex_init(&rctx->lock);
+	}
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 
 	result = getrdataset(mctx, &rdataset);
 	if (result != ISC_R_SUCCESS)
@@ -1401,7 +1414,9 @@ dns_client_startresolve(dns_client_t *client, const dns_name_t *name,
 	rctx->sigrdataset = sigrdataset;
 
 	dns_fixedname_init(&rctx->name);
-	dns_name_copynf(name, dns_fixedname_name(&rctx->name));
+	result = dns_name_copy(name, dns_fixedname_name(&rctx->name), NULL);
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 
 	rctx->client = client;
 	ISC_LINK_INIT(rctx, link);
@@ -1419,7 +1434,6 @@ dns_client_startresolve(dns_client_t *client, const dns_name_t *name,
 	rctx->event = event;
 
 	rctx->magic = RCTX_MAGIC;
-	isc_refcount_increment(&client->references);
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->resctxs, rctx, link);
@@ -1490,10 +1504,10 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 	resctx_t *rctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 
 	REQUIRE(transp != NULL);
 	rctx = (resctx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(RCTX_VALID(rctx));
 	REQUIRE(rctx->fetch == NULL);
 	REQUIRE(rctx->event == NULL);
@@ -1515,6 +1529,11 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(rctx, link));
 	ISC_LIST_UNLINK(client->resctxs, rctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs))
+		need_destroyclient = true;
+
 	UNLOCK(&client->lock);
 
 	INSIST(ISC_LIST_EMPTY(rctx->namelist));
@@ -1524,8 +1543,10 @@ dns_client_destroyrestrans(dns_clientrestrans_t **transp) {
 
 	isc_mem_put(mctx, rctx, sizeof(*rctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
 
+	*transp = NULL;
 }
 
 isc_result_t
@@ -1769,7 +1790,13 @@ dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
 	}
 
 	ctx = isc_mem_get(client->mctx, sizeof(*ctx));
-	isc_mutex_init(&ctx->lock);
+	if (ctx == NULL)
+		result = ISC_R_NOMEMORY;
+	else {
+		isc_mutex_init(&ctx->lock);
+	}
+	if (result != ISC_R_SUCCESS)
+		goto cleanup;
 
 	ctx->client = client;
 	ISC_LINK_INIT(ctx, link);
@@ -1785,7 +1812,6 @@ dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->reqctxs, ctx, link);
-	isc_refcount_increment(&client->references);
 	UNLOCK(&client->lock);
 
 	ctx->request = NULL;
@@ -1800,9 +1826,7 @@ dns_client_startrequest(dns_client_t *client, dns_message_t *qmessage,
 		return (ISC_R_SUCCESS);
 	}
 
-	isc_refcount_decrement(&client->references);
-
-cleanup:
+ cleanup:
 	if (ctx != NULL) {
 		LOCK(&client->lock);
 		ISC_LIST_UNLINK(client->reqctxs, ctx, link);
@@ -1810,8 +1834,8 @@ cleanup:
 		isc_mutex_destroy(&ctx->lock);
 		isc_mem_put(client->mctx, ctx, sizeof(*ctx));
 	}
-
-	isc_event_free(ISC_EVENT_PTR(&event));
+	if (event != NULL)
+		isc_event_free(ISC_EVENT_PTR(&event));
 	isc_task_detach(&tclone);
 	dns_view_detach(&view);
 
@@ -1842,10 +1866,10 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 	reqctx_t *ctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 
 	REQUIRE(transp != NULL);
 	ctx = (reqctx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(REQCTX_VALID(ctx));
 	client = ctx->client;
 	REQUIRE(DNS_CLIENT_VALID(client));
@@ -1860,6 +1884,12 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(ctx, link));
 	ISC_LIST_UNLINK(client->reqctxs, ctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs)) {
+		need_destroyclient = true;
+	}
+
 	UNLOCK(&client->lock);
 
 	isc_mutex_destroy(&ctx->lock);
@@ -1867,7 +1897,10 @@ dns_client_destroyreqtrans(dns_clientreqtrans_t **transp) {
 
 	isc_mem_put(mctx, ctx, sizeof(*ctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
+
+	*transp = NULL;
 }
 
 /*%
@@ -2209,7 +2242,9 @@ process_soa(updatectx_t *uctx, dns_rdataset_t *soaset,
 
 	if (uctx->zonename == NULL) {
 		uctx->zonename = dns_fixedname_name(&uctx->zonefname);
-		dns_name_copynf(soaname, uctx->zonename);
+		result = dns_name_copy(soaname, uctx->zonename, NULL);
+		if (result != ISC_R_SUCCESS)
+			goto out;
 	}
 
 	if (uctx->currentserver != NULL)
@@ -2246,6 +2281,7 @@ process_soa(updatectx_t *uctx, dns_rdataset_t *soaset,
 		UNLOCK(&uctx->lock);
 	}
 
+ out:
 	dns_rdata_freestruct(&soa);
 
 	return (result);
@@ -2585,7 +2621,9 @@ copy_name(isc_mem_t *mctx, dns_message_t *msg, const dns_name_t *name,
 	dns_name_init(newname, NULL);
 	dns_name_setbuffer(newname, namebuf);
 	dns_message_takebuffer(msg, &namebuf);
-	dns_name_copynf(name, newname);
+	result = dns_name_copy(name, newname, NULL);
+	if (result != ISC_R_SUCCESS)
+		goto fail;
 
 	for (rdataset = ISC_LIST_HEAD(name->list); rdataset != NULL;
 	     rdataset = ISC_LIST_NEXT(rdataset, link)) {
@@ -2884,7 +2922,7 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 		goto fail;
 	if (zonename != NULL) {
 		uctx->zonename = dns_fixedname_name(&uctx->zonefname);
-		dns_name_copynf(zonename, uctx->zonename);
+		result = dns_name_copy(zonename, uctx->zonename, NULL);
 	}
 	if (servers != NULL) {
 		for (server = ISC_LIST_HEAD(*servers);
@@ -2948,7 +2986,6 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 
 	LOCK(&client->lock);
 	ISC_LIST_APPEND(client->updatectxs, uctx, link);
-	isc_refcount_increment(&client->references);
 	UNLOCK(&client->lock);
 
 	*transp = (dns_clientupdatetrans_t *)uctx;
@@ -2967,8 +3004,6 @@ dns_client_startupdate(dns_client_t *client, dns_rdataclass_t rdclass,
 	}
 	if (result == ISC_R_SUCCESS)
 		return (result);
-
-	isc_refcount_decrement(&client->references);
 	*transp = NULL;
 
  fail:
@@ -3026,11 +3061,11 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 	updatectx_t *uctx;
 	isc_mem_t *mctx;
 	dns_client_t *client;
+	bool need_destroyclient = false;
 	isc_sockaddr_t *sa;
 
 	REQUIRE(transp != NULL);
 	uctx = (updatectx_t *)*transp;
-	*transp = NULL;
 	REQUIRE(UCTX_VALID(uctx));
 	client = uctx->client;
 	REQUIRE(DNS_CLIENT_VALID(client));
@@ -3051,6 +3086,11 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 	INSIST(ISC_LINK_LINKED(uctx, link));
 	ISC_LIST_UNLINK(client->updatectxs, uctx, link);
 
+	if (client->references == 0 && ISC_LIST_EMPTY(client->resctxs) &&
+	    ISC_LIST_EMPTY(client->reqctxs) &&
+	    ISC_LIST_EMPTY(client->updatectxs))
+		need_destroyclient = true;
+
 	UNLOCK(&client->lock);
 
 	isc_mutex_destroy(&uctx->lock);
@@ -3058,7 +3098,10 @@ dns_client_destroyupdatetrans(dns_clientupdatetrans_t **transp) {
 
 	isc_mem_put(mctx, uctx, sizeof(*uctx));
 
-	dns_client_destroy(&client);
+	if (need_destroyclient)
+		destroyclient(&client);
+
+	*transp = NULL;
 }
 
 isc_mem_t *
