@@ -12,8 +12,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <inttypes.h>
 #include <stdbool.h>
@@ -458,16 +456,15 @@ dns_name_hash(const dns_name_t *name, bool case_sensitive) {
 	 */
 	REQUIRE(VALID_NAME(name));
 
-	if (name->labels == 0) {
+	if (name->labels == 0)
 		return (0);
-	}
 
 	length = name->length;
-	if (length > 16) {
+	if (length > 16)
 		length = 16;
-	}
 
-	return (isc_hash_function(name->ndata, length, case_sensitive));
+	return (isc_hash_function_reverse(name->ndata, length,
+					  case_sensitive, NULL));
 }
 
 unsigned int
@@ -477,11 +474,11 @@ dns_name_fullhash(const dns_name_t *name, bool case_sensitive) {
 	 */
 	REQUIRE(VALID_NAME(name));
 
-	if (name->labels == 0) {
+	if (name->labels == 0)
 		return (0);
-	}
 
-	return (isc_hash_function(name->ndata, name->length, case_sensitive));
+	return (isc_hash_function_reverse(name->ndata, name->length,
+					  case_sensitive, NULL));
 }
 
 dns_namereln_t
@@ -1348,7 +1345,7 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 	unsigned int trem, count;
 	unsigned int labels;
 	bool saw_root = false;
-	unsigned int oused;
+	unsigned int oused = target->used;
 	dns_name_totextfilter_t *mem;
 	dns_name_totextfilter_t totext_filter_proc = NULL;
 	isc_result_t result;
@@ -1361,8 +1358,6 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 	REQUIRE(VALID_NAME(name));
 	REQUIRE(ISC_BUFFER_VALID(target));
 
-	oused = target->used;
-
 	result = totext_filter_proc_key_init();
 	if (result != ISC_R_SUCCESS)
 		return (result);
@@ -2380,10 +2375,15 @@ dns_name_format(const dns_name_t *name, char *cp, unsigned int size) {
 	isc_buffer_init(&buf, cp, size - 1);
 	result = dns_name_totext(name, true, &buf);
 	if (result == ISC_R_SUCCESS) {
-		isc_buffer_putuint8(&buf, (uint8_t)'\0');
-	} else {
+		/*
+		 * Null terminate.
+		 */
+		isc_region_t r;
+		isc_buffer_usedregion(&buf, &r);
+		((char *) r.base)[r.length] = '\0';
+
+	} else
 		snprintf(cp, size, "<unknown>");
-	}
 }
 
 /*
@@ -2456,46 +2456,50 @@ dns_name_fromstring2(dns_name_t *target, const char *src,
 	return (result);
 }
 
-static
 isc_result_t
-name_copy(const dns_name_t *source, dns_name_t *dest, isc_buffer_t *target) {
+dns_name_copy(const dns_name_t *source, dns_name_t *dest, isc_buffer_t *target) {
 	unsigned char *ndata;
 
 	/*
 	 * Make dest a copy of source.
 	 */
 
+	REQUIRE(VALID_NAME(source));
+	REQUIRE(VALID_NAME(dest));
+	REQUIRE(target != NULL || dest->buffer != NULL);
+
+	if (target == NULL) {
+		target = dest->buffer;
+		isc_buffer_clear(dest->buffer);
+	}
+
 	REQUIRE(BINDABLE(dest));
 
 	/*
 	 * Set up.
 	 */
-	if (target->length - target->used < source->length) {
+	if (target->length - target->used < source->length)
 		return (ISC_R_NOSPACE);
-	}
 
 	ndata = (unsigned char *)target->base + target->used;
 	dest->ndata = target->base;
 
-	if (source->length != 0) {
+	if (source->length != 0)
 		memmove(ndata, source->ndata, source->length);
-	}
 
 	dest->ndata = ndata;
 	dest->labels = source->labels;
 	dest->length = source->length;
-	if ((source->attributes & DNS_NAMEATTR_ABSOLUTE) != 0) {
+	if ((source->attributes & DNS_NAMEATTR_ABSOLUTE) != 0)
 		dest->attributes = DNS_NAMEATTR_ABSOLUTE;
-	} else {
+	else
 		dest->attributes = 0;
-	}
 
 	if (dest->labels > 0 && dest->offsets != NULL) {
-		if (source->offsets != NULL) {
+		if (source->offsets != NULL)
 			memmove(dest->offsets, source->offsets, source->labels);
-		} else {
+		else
 			set_offsets(dest, dest->offsets, NULL);
-		}
 	}
 
 	isc_buffer_add(target, dest->length);
@@ -2503,27 +2507,6 @@ name_copy(const dns_name_t *source, dns_name_t *dest, isc_buffer_t *target) {
 	return (ISC_R_SUCCESS);
 }
 
-isc_result_t
-dns_name_copy(const dns_name_t *source, dns_name_t *dest, isc_buffer_t *target)
-{
-	REQUIRE(VALID_NAME(source));
-	REQUIRE(VALID_NAME(dest));
-	REQUIRE(target != NULL);
-
-	return (name_copy(source, dest, target));
-}
-
-void
-dns_name_copynf(const dns_name_t *source, dns_name_t *dest)
-{
-	REQUIRE(VALID_NAME(source));
-	REQUIRE(VALID_NAME(dest));
-	REQUIRE(dest->buffer != NULL);
-
-	isc_buffer_clear(dest->buffer);
-	RUNTIME_CHECK(name_copy(source, dest, dest->buffer) == ISC_R_SUCCESS);
-}
-
 void
 dns_name_destroy(void) {
 	RUNTIME_CHECK(isc_once_do(&once, thread_key_mutex_init)
