@@ -9,9 +9,6 @@
  * information regarding copyright ownership.
  */
 
-
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 
@@ -1929,7 +1926,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 	 */
 	if (dns_name_countlabels(zonename) == 0 ||
 	    dns_name_issubdomain(zone, zonename))
-		dns_name_copynf(zone, zonename);
+		dns_name_copy(zone, zonename, NULL);
 
 	if (!dns_name_equal(zone, zonename))
 		return (ISC_R_IGNORE);
@@ -2072,7 +2069,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 				(*logit)(arg, ISC_LOG_DEBUG(3),
 					 "NSEC3 indicates potential closest "
 					 "encloser: '%s'", namebuf);
-				dns_name_copynf(qname, closest);
+				dns_name_copy(qname, closest, NULL);
 				*setclosest = true;
 			}
 			dns_name_format(qname, namebuf, sizeof(namebuf));
@@ -2103,7 +2100,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 			if (nearest != NULL &&
 			    (dns_name_countlabels(nearest) == 0 ||
 			     dns_name_issubdomain(nearest, qname))) {
-				dns_name_copynf(qname, nearest);
+				dns_name_copy(qname, nearest, NULL);
 				*setnearest = true;
 			}
 
