@@ -11,8 +11,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 #include <sys/stat.h>
@@ -1047,7 +1045,9 @@ chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 	if (include_chain_end && chain->end != NULL) {
 		NODENAME(chain->end, &nodename);
-		dns_name_copynf(&nodename, name);
+		result = dns_name_copy(&nodename, name, NULL);
+		if (result != ISC_R_SUCCESS)
+			return (result);
 	} else
 		dns_name_reset(name);
 
@@ -2688,7 +2688,6 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 	 * Fix color violations.
 	 */
 	if (IS_BLACK(item)) {
-		/* cppcheck-suppress nullPointerRedundantCheck symbolName=item */
 		parent = PARENT(item);
 
 		while (child != *rootp && IS_BLACK(child)) {
@@ -2706,7 +2705,6 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 				INSIST(sibling != NULL);
 
-				/* cppcheck-suppress nullPointerRedundantCheck symbolName=sibling */
 				if (IS_BLACK(LEFT(sibling)) &&
 				    IS_BLACK(RIGHT(sibling))) {
 					MAKE_RED(sibling);
@@ -2746,7 +2744,6 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 				INSIST(sibling != NULL);
 
-				/* cppcheck-suppress nullPointerRedundantCheck symbolName=sibling */
 				if (IS_BLACK(LEFT(sibling)) &&
 				    IS_BLACK(RIGHT(sibling))) {
 					MAKE_RED(sibling);
@@ -2878,7 +2875,6 @@ check_properties_helper(dns_rbtnode_t *node) {
 			return (false);
 	}
 
-	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node))))
 		return (false);
 
@@ -2916,15 +2912,12 @@ check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 		return (true);
 	}
 
-	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(LEFT(node), &dl))
 		return (false);
 
-	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(RIGHT(node), &dr))
 		return (false);
 
-	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(DOWN(node), &dd))
 		return (false);
 
@@ -2967,12 +2960,6 @@ dns_rbt_indent(FILE *f, int depth) {
 
 void
 dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
-
-	if (n == NULL) {
-		fprintf(f, "Null node\n");
-		return;
-	}
-
 	fprintf(f, "Node info for nodename: ");
 	printnodename(n, true, f);
 	fprintf(f, "\n");
@@ -2992,7 +2979,7 @@ dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 	fprintf(f, "Right: %p\n", n->right);
 	fprintf(f, "Left: %p\n", n->left);
 	fprintf(f, "Down: %p\n", n->down);
-	fprintf(f, "Data: %p\n", n->data);
+	fprintf(f, "daTa: %p\n", n->data);
 }
 
 static void
@@ -3025,12 +3012,8 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 
 	if (root != NULL) {
 		printnodename(root, true, f);
-		/*
-		 * Don't use IS_RED(root) as it tests for 'root != NULL'
-		 * and cppcheck produces false positives.
-		 */
 		fprintf(f, " (%s, %s", direction,
-			COLOR(root) == RED ? "RED" : "BLACK");
+			IS_RED(root) ? "RED" : "BLACK");
 
 		if ((! IS_ROOT(root) && PARENT(root) != parent) ||
 		    (  IS_ROOT(root) && depth > 0 &&
@@ -3054,22 +3037,13 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 
 		depth++;
 
-		/*
-		 * Don't use IS_RED(root) as it tests for 'root != NULL'
-		 * and cppcheck produces false positives.
-		 */
-		if (COLOR(root) == RED && IS_RED(LEFT(root))) {
+		if (IS_RED(root) && IS_RED(LEFT(root)))
 			fprintf(f, "** Red/Red color violation on left\n");
-		}
 		print_text_helper(LEFT(root), root, depth, "left",
 					  data_printer, f);
 
-		/*
-		 * Don't use IS_RED(root) as cppcheck produces false positives.
-		 */
-		if (COLOR(root) == RED && IS_RED(RIGHT(root))) {
+		if (IS_RED(root) && IS_RED(RIGHT(root)))
 			fprintf(f, "** Red/Red color violation on right\n");
-		}
 		print_text_helper(RIGHT(root), root, depth, "right",
 					  data_printer, f);
 
@@ -3209,11 +3183,10 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 	}
 
 	if (origin != NULL) {
-		if (chain->level_count > 0) {
+		if (chain->level_count > 0)
 			result = chain_name(chain, origin, false);
-		} else {
-			dns_name_copynf(dns_rootname, origin);
-		}
+		else
+			result = dns_name_copy(dns_rootname, origin, NULL);
 	}
 
 	return (result);
