@@ -11,8 +11,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 #include <string.h>
@@ -710,82 +708,6 @@ destroynode(dns_sdbnode_t *node) {
 	detach((dns_db_t **) (void *)&sdb);
 }
 
-static isc_result_t
-getoriginnode(dns_db_t *db, dns_dbnode_t **nodep) {
-	dns_sdb_t *sdb = (dns_sdb_t *)db;
-	dns_sdbnode_t *node = NULL;
-	isc_result_t result;
-	isc_buffer_t b;
-	char namestr[DNS_NAME_MAXTEXT + 1];
-	dns_sdbimplementation_t *imp;
-	dns_name_t relname;
-	dns_name_t *name;
-
-	REQUIRE(VALID_SDB(sdb));
-	REQUIRE(nodep != NULL && *nodep == NULL);
-
-	imp = sdb->implementation;
-	name = &sdb->common.origin;
-
-	if (imp->methods->lookup2 != NULL) {
-		if ((imp->flags & DNS_SDBFLAG_RELATIVEOWNER) != 0) {
-			dns_name_init(&relname, NULL);
-			name = &relname;
-		}
-	} else {
-		isc_buffer_init(&b, namestr, sizeof(namestr));
-		if ((imp->flags & DNS_SDBFLAG_RELATIVEOWNER) != 0) {
-
-			dns_name_init(&relname, NULL);
-			result = dns_name_totext(&relname, true, &b);
-			if (result != ISC_R_SUCCESS) {
-				return (result);
-			}
-		} else {
-			result = dns_name_totext(name, true, &b);
-			if (result != ISC_R_SUCCESS) {
-				return (result);
-			}
-		}
-		isc_buffer_putuint8(&b, 0);
-	}
-
-	result = createnode(sdb, &node);
-	if (result != ISC_R_SUCCESS) {
-		return (result);
-	}
-
-	MAYBE_LOCK(sdb);
-	if (imp->methods->lookup2 != NULL) {
-		result = imp->methods->lookup2(&sdb->common.origin, name,
-					       sdb->dbdata, node, NULL, NULL);
-	} else {
-		result = imp->methods->lookup(sdb->zone, namestr, sdb->dbdata,
-					      node, NULL, NULL);
-	}
-	MAYBE_UNLOCK(sdb);
-	if (result != ISC_R_SUCCESS &&
-	    !(result == ISC_R_NOTFOUND &&
-	      imp->methods->authority != NULL))
-	{
-		destroynode(node);
-		return (result);
-	}
-
-	if (imp->methods->authority != NULL) {
-		MAYBE_LOCK(sdb);
-		result = imp->methods->authority(sdb->zone, sdb->dbdata, node);
-		MAYBE_UNLOCK(sdb);
-		if (result != ISC_R_SUCCESS) {
-			destroynode(node);
-			return (result);
-		}
-	}
-
-	*nodep = node;
-	return (ISC_R_SUCCESS);
-}
-
 static isc_result_t
 findnodeext(dns_db_t *db, const dns_name_t *name, bool create,
 	    dns_clientinfomethods_t *methods, dns_clientinfo_t *clientinfo,
@@ -1031,7 +953,16 @@ findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 		dns_rdataset_disassociate(rdataset);
 
 	if (foundname != NULL) {
-		dns_name_copynf(xname, foundname);
+		isc_result_t xresult;
+
+		xresult = dns_name_copy(xname, foundname, NULL);
+		if (xresult != ISC_R_SUCCESS) {
+			if (node != NULL)
+				destroynode(node);
+			if (dns_rdataset_isassociated(rdataset))
+				dns_rdataset_disassociate(rdataset);
+			return (DNS_R_BADDB);
+		}
 	}
 
 	if (nodep != NULL)
@@ -1127,11 +1058,10 @@ createiterator(dns_db_t *db, unsigned int options, dns_dbiterator_t **iteratorp)
 {
 	dns_sdb_t *sdb = (dns_sdb_t *)db;
 	sdb_dbiterator_t *sdbiter;
-	dns_sdbimplementation_t *imp;
+	dns_sdbimplementation_t *imp = sdb->implementation;
 	isc_result_t result;
 
 	REQUIRE(VALID_SDB(sdb));
-	imp = sdb->implementation;
 
 	if (imp->methods->allnodes == NULL)
 		return (ISC_R_NOTIMPLEMENTED);
@@ -1180,7 +1110,7 @@ findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	dns_rdatalist_t *list;
 	dns_sdbnode_t *sdbnode = (dns_sdbnode_t *)node;
 
-	REQUIRE(VALID_SDBNODE(sdbnode));
+	REQUIRE(VALID_SDBNODE(node));
 
 	UNUSED(db);
 	UNUSED(version);
@@ -1339,7 +1269,7 @@ static dns_dbmethods_t sdb_methods = {
 	ispersistent,
 	overmem,
 	settask,
-	getoriginnode,		/* getoriginnode */
+	NULL,			/* getoriginnode */
 	NULL,			/* transfernode */
 	NULL,			/* getnsec3parameters */
 	NULL,			/* findnsec3node */
@@ -1593,10 +1523,8 @@ dbiterator_current(dns_dbiterator_t *iterator, dns_dbnode_t **nodep,
 	sdb_dbiterator_t *sdbiter = (sdb_dbiterator_t *)iterator;
 
 	attachnode(iterator->db, sdbiter->current, nodep);
-	if (name != NULL) {
-		dns_name_copynf(sdbiter->current->name, name);
-		return (ISC_R_SUCCESS);
-	}
+	if (name != NULL)
+		return (dns_name_copy(sdbiter->current->name, name, NULL));
 	return (ISC_R_SUCCESS);
 }
 
@@ -1609,8 +1537,7 @@ dbiterator_pause(dns_dbiterator_t *iterator) {
 static isc_result_t
 dbiterator_origin(dns_dbiterator_t *iterator, dns_name_t *name) {
 	UNUSED(iterator);
-	dns_name_copynf(dns_rootname, name);
-	return (ISC_R_SUCCESS);
+	return (dns_name_copy(dns_rootname, name, NULL));
 }
 
 /*
