@@ -9,15 +9,12 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -28,12 +25,11 @@
 #include <isc/util.h>
 #include <isc/string.h>
 
-#include <dns/name.h>
-
-#include <dst/result.h>
-
 #include <pk11/site.h>
 
+#include <dns/name.h>
+#include <dst/result.h>
+
 #include "../dst_internal.h"
 
 #include "dnstest.h"
