@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
@@ -18,7 +16,6 @@
 #include <setjmp.h>
 
 #include <inttypes.h>
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -169,7 +166,6 @@ send_test(void **state) {
 	cleanup();
 
 	result = dns_test_makeview("test", &view);
-	assert_int_equal(result, ISC_R_SUCCESS);
 
 	fopt = fstrm_iothr_options_init();
 	assert_non_null(fopt);
@@ -194,7 +190,6 @@ send_test(void **state) {
 	memset(&zr, 0, sizeof(zr));
 	isc_buffer_init(&zb, zone, sizeof(zone));
 	result = dns_compress_init(&cctx, -1, mctx);
-	assert_int_equal(result, ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, DNS_COMPRESS_NONE);
 	result = dns_name_towire(zname, &cctx, &zb);
 	assert_int_equal(result, ISC_R_SUCCESS);
