@@ -9,28 +9,26 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdlib.h>
 #include <unistd.h>
 
 #define UNIT_TESTING
 #include <cmocka.h>
 
+#include <isc/util.h>
+
 #include <isc/app.h>
 #include <isc/buffer.h>
 #include <isc/print.h>
 #include <isc/socket.h>
 #include <isc/task.h>
 #include <isc/timer.h>
-#include <isc/util.h>
 
 #include <dns/dispatch.h>
 #include <dns/name.h>
