@@ -9,16 +9,12 @@
  * information regarding copyright ownership.
  */
 
-
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
