@@ -9,23 +9,16 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
+#include <stdbool.h>
 #include <stddef.h>
 #include <setjmp.h>
-
-#include <sched.h> /* IWYU pragma: keep */
-#include <stdbool.h>
-#include <stdlib.h>
-
 #include <cmocka.h>
 
 #include <isc/mem.h>
 #include <isc/result.h>
-#include <isc/util.h>
 
 #include <dns/tkey.h>
 
@@ -36,78 +29,35 @@ static isc_mem_t mock_mctx = {
 	.methods = NULL
 };
 
-void *
-__wrap_isc__mem_get(isc_mem_t *mctx, size_t size);
-void
-__wrap_isc__mem_put(isc_mem_t *ctx0, void *ptr, size_t size);
-void
-__wrap_isc_mem_attach(isc_mem_t *source0, isc_mem_t **targetp);
-void
-__wrap_isc_mem_detach(isc_mem_t **ctxp);
-
-void *
-__wrap_isc__mem_get(isc_mem_t *mctx, size_t size)
+static void *
+__wrap_isc__mem_get(isc_mem_t *mctx __attribute__ ((unused)),
+		   size_t size)
 {
 	bool has_enough_memory = mock_type(bool);
-
-	UNUSED(mctx);
-
 	if (!has_enough_memory) {
 		return (NULL);
 	}
 	return (malloc(size));
 }
 
-void
-__wrap_isc__mem_put(isc_mem_t *ctx0, void *ptr, size_t size) {
-	UNUSED(ctx0);
-	UNUSED(size);
-
+static void
+__wrap_isc__mem_put(isc_mem_t *ctx0 __attribute__ ((unused)),
+		   void *ptr,
+		   size_t size __attribute__ ((unused)))
+{
 	free(ptr);
 }
 
-void
+static void
 __wrap_isc_mem_attach(isc_mem_t *source0, isc_mem_t **targetp) {
 	*targetp = source0;
 }
 
-void
+static void
 __wrap_isc_mem_detach(isc_mem_t **ctxp) {
 	*ctxp = NULL;
 }
 
-#if ISC_MEM_TRACKLINES
-#define FLARG		, const char *file, unsigned int line
-#else
-#define FLARG
-#endif
-
-__attribute__((weak)) void *
-isc__mem_get(isc_mem_t *mctx, size_t size FLARG)
-{
-	UNUSED(file);
-	UNUSED(line);
-	return (__wrap_isc__mem_get(mctx, size));
-}
-
-__attribute__((weak)) void
-isc__mem_put(isc_mem_t *ctx0, void *ptr, size_t size FLARG)
-{
-	UNUSED(file);
-	UNUSED(line);
-	__wrap_isc__mem_put(ctx0, ptr, size);
-}
-
-__attribute__((weak)) void
-isc_mem_attach(isc_mem_t *source0, isc_mem_t **targetp) {
-	__wrap_isc_mem_attach(source0, targetp);
-}
-
-__attribute__((weak)) void
-isc_mem_detach(isc_mem_t **ctxp) {
-	__wrap_isc_mem_detach(ctxp);
-}
-
 static int
 _setup(void **state) {
 	dns_tkeyctx_t *tctx = NULL;
@@ -149,6 +99,7 @@ dns_tkeyctx_destroy_test(void **state) {
 	assert_non_null(tctx);
 	dns_tkeyctx_destroy(&tctx);
 }
+
 #endif /* LD_WRAP */
 
 int
@@ -169,12 +120,12 @@ main(void) {
 #endif
 	};
 	return (cmocka_run_group_tests(tkey_tests, NULL, NULL));
-#else /* LD_WRAP */
+#else
 	print_message("1..0 # Skip tkey_test requires LD_WRAP\n");
 #endif /* LD_WRAP */
 }
 
-#else /* CMOCKA */
+#else
 
 #include <stdio.h>
 
@@ -184,4 +135,4 @@ main(void) {
 	return (0);
 }
 
-#endif /* CMOCKA */
+#endif
