@@ -9,9 +9,6 @@
  * information regarding copyright ownership.
  */
 
-
-#include <config.h>
-
 #include <stdbool.h>
 
 #include <isc/app.h>
@@ -135,7 +132,7 @@ free_specific_context(void *arg) {
 
 static void
 thread_key_mutex_init(void) {
-	RUNTIME_CHECK(isc_mutex_init(&thread_key_mutex) == ISC_R_SUCCESS);
+	isc_mutex_init(&thread_key_mutex);
 }
 
 static isc_result_t
