@@ -12,8 +12,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <errno.h>
 #include <inttypes.h>
@@ -855,6 +853,7 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 			FATAL_ERROR(__FILE__, __LINE__,
 				    "Unexpected state %d",
 				    state);
+			ISC_UNREACHABLE();
 		}
 
 	} while (!done);
