@@ -16,8 +16,6 @@
  * for changing states.
  */
 
-#include <config.h>
-
 #include <stdbool.h>
 
 #include <isc/app.h>
@@ -1382,7 +1380,7 @@ isc_taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 		RUNTIME_CHECK(isc_thread_create(run, &manager->queues[i],
 						&manager->queues[i].thread)
 			      == ISC_R_SUCCESS);
-		char name[21];
+		char name[16];
 		snprintf(name, sizeof(name), "isc-worker%04u", i);
 		isc_thread_setname(manager->queues[i].thread, name);
 	}
@@ -1570,12 +1568,10 @@ isc_taskmgr_excltask(isc_taskmgr_t *mgr0, isc_task_t **taskp) {
 isc_result_t
 isc_task_beginexclusive(isc_task_t *task0) {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc__taskmgr_t *manager;
+	isc__taskmgr_t *manager = task->manager;
 
 	REQUIRE(VALID_TASK(task));
 
-	manager = task->manager;
-
 	REQUIRE(task->state == task_state_running);
 
 	LOCK(&manager->excl_lock);
@@ -1604,13 +1600,10 @@ isc_task_beginexclusive(isc_task_t *task0) {
 void
 isc_task_endexclusive(isc_task_t *task0) {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc__taskmgr_t *manager;
+	isc__taskmgr_t *manager = task->manager;
 
 	REQUIRE(VALID_TASK(task));
 	REQUIRE(task->state == task_state_running);
-
-	manager = task->manager;
-
 	LOCK(&manager->halt_lock);
 	REQUIRE(atomic_load_relaxed(&manager->exclusive_req) == true);
 	atomic_store_relaxed(&manager->exclusive_req, false);
