@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
@@ -18,7 +16,6 @@
 #include <setjmp.h>
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 
 #define UNIT_TESTING
