@@ -9,17 +9,14 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <errno.h>
-#include <stdlib.h>
 #include <string.h>
+#include <sys/errno.h>
 
 #define UNIT_TESTING
 #include <cmocka.h>
