@@ -9,15 +9,12 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 #if HAVE_CMOCKA
 
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -29,6 +26,7 @@
 #include <isc/taskpool.h>
 #include <isc/util.h>
 
+
 #include "isctest.h"
 
 static int
