@@ -12,8 +12,6 @@
 
 /*! \file */
 
-#include <config.h>
-
 #include <stdbool.h>
 
 #include <isc/app.h>
@@ -240,11 +238,7 @@ isc_timer_create(isc_timermgr_t *manager0, isc_timertype_t type,
 		 isc_task_t *task, isc_taskaction_t action, void *arg,
 		 isc_timer_t **timerp)
 {
-	REQUIRE(VALID_MANAGER(manager0));
-	REQUIRE(task != NULL);
-	REQUIRE(action != NULL);
-
-	isc__timermgr_t *manager;
+	isc__timermgr_t *manager = (isc__timermgr_t *)manager0;
 	isc__timer_t *timer;
 	isc_result_t result;
 	isc_time_t now;
@@ -256,7 +250,10 @@ isc_timer_create(isc_timermgr_t *manager0, isc_timertype_t type,
 	 * called with 'arg' as the arg value.  The new timer is returned
 	 * in 'timerp'.
 	 */
-	manager = (isc__timermgr_t *)manager0;
+
+	REQUIRE(VALID_MANAGER(manager));
+	REQUIRE(task != NULL);
+	REQUIRE(action != NULL);
 	if (expires == NULL)
 		expires = isc_time_epoch;
 	if (interval == NULL)
@@ -356,7 +353,7 @@ isc_timer_reset(isc_timer_t *timer0, isc_timertype_t type,
 		 const isc_time_t *expires, const isc_interval_t *interval,
 		 bool purge)
 {
-	isc__timer_t *timer;
+	isc__timer_t *timer = (isc__timer_t *)timer0;
 	isc_time_t now;
 	isc__timermgr_t *manager;
 	isc_result_t result;
@@ -367,8 +364,7 @@ isc_timer_reset(isc_timer_t *timer0, isc_timertype_t type,
 	 * are purged from its task's event queue.
 	 */
 
-	REQUIRE(VALID_TIMER(timer0));
-	timer = (isc__timer_t *)timer0;
+	REQUIRE(VALID_TIMER(timer));
 	manager = timer->manager;
 	REQUIRE(VALID_MANAGER(manager));
 
@@ -430,11 +426,10 @@ isc_timer_reset(isc_timer_t *timer0, isc_timertype_t type,
 
 isc_timertype_t
 isc_timer_gettype(isc_timer_t *timer0) {
-	isc__timer_t *timer;
+	isc__timer_t *timer = (isc__timer_t *)timer0;
 	isc_timertype_t t;
 
-	REQUIRE(VALID_TIMER(timer0));
-	timer = (isc__timer_t *)timer0;
+	REQUIRE(VALID_TIMER(timer));
 
 	LOCK(&timer->lock);
 	t = timer->type;
@@ -445,7 +440,7 @@ isc_timer_gettype(isc_timer_t *timer0) {
 
 isc_result_t
 isc_timer_touch(isc_timer_t *timer0) {
-	isc__timer_t *timer;
+	isc__timer_t *timer = (isc__timer_t *)timer0;
 	isc_result_t result;
 	isc_time_t now;
 
@@ -453,8 +448,7 @@ isc_timer_touch(isc_timer_t *timer0) {
 	 * Set the last-touched time of 'timer' to the current time.
 	 */
 
-	REQUIRE(VALID_TIMER(timer0));
-	timer = (isc__timer_t *)timer0;
+	REQUIRE(VALID_TIMER(timer));
 
 	LOCK(&timer->lock);
 
@@ -477,14 +471,13 @@ isc_timer_touch(isc_timer_t *timer0) {
 
 void
 isc_timer_attach(isc_timer_t *timer0, isc_timer_t **timerp) {
-	isc__timer_t *timer;
+	isc__timer_t *timer = (isc__timer_t *)timer0;
 
 	/*
 	 * Attach *timerp to timer.
 	 */
 
-	REQUIRE(VALID_TIMER(timer0));
-	timer = (isc__timer_t *)timer0;
+	REQUIRE(VALID_TIMER(timer));
 	REQUIRE(timerp != NULL && *timerp == NULL);
 
 	LOCK(&timer->lock);
@@ -679,8 +672,8 @@ static void
 set_index(void *what, unsigned int index) {
 	isc__timer_t *timer;
 
-	REQUIRE(VALID_TIMER(what));
 	timer = what;
+	REQUIRE(VALID_TIMER(timer));
 
 	timer->index = index;
 }
@@ -737,10 +730,9 @@ isc_timermgr_create(isc_mem_t *mctx, isc_timermgr_t **managerp) {
 
 void
 isc_timermgr_poke(isc_timermgr_t *manager0) {
-	isc__timermgr_t *manager;
+	isc__timermgr_t *manager = (isc__timermgr_t *)manager0;
 
-	REQUIRE(VALID_MANAGER(manager0));
-	manager = (isc__timermgr_t *)manager0;
+	REQUIRE(VALID_MANAGER(manager));
 
 	SIGNAL(&manager->wakeup);
 }
