@@ -9,13 +9,10 @@
  * information regarding copyright ownership.
  */
 
-
-#include <config.h>
-
 #include <stdbool.h>
 #include <sys/types.h>
 
-#if defined(HAVE_SYS_SYSCTL_H) && !defined(__linux__)
+#if defined(HAVE_SYS_SYSCTL_H)
 #if defined(HAVE_SYS_PARAM_H)
 #include <sys/param.h>
 #endif
