@@ -9,8 +9,6 @@
  * information regarding copyright ownership.
  */
 
-#include <config.h>
-
 /* This code uses functions which are only available on Server 2003 and
  * higher, and Windows XP and higher.
  *
@@ -300,20 +298,19 @@ typedef struct IoCompletionInfo {
 
 struct isc_socketmgr {
 	/* Not locked. */
-	unsigned int		magic;
-	isc_mem_t	       *mctx;
-	isc_mutex_t		lock;
-	isc_stats_t	       *stats;
+	unsigned int			magic;
+	isc_mem_t		       *mctx;
+	isc_mutex_t			lock;
+	isc_stats_t		       *stats;
 
 	/* Locked by manager lock. */
-	ISC_LIST(isc_socket_t)	socklist;
+	ISC_LIST(isc_socket_t)		socklist;
 	bool			bShutdown;
-	isc_condition_t		shutdown_ok;
-	HANDLE			hIoCompletionPort;
-	int			maxIOCPThreads;
-	HANDLE			hIOCPThreads[MAX_IOCPTHREADS];
-	DWORD			dwIOCPThreadIds[MAX_IOCPTHREADS];
-	size_t			maxudp;
+	isc_condition_t			shutdown_ok;
+	HANDLE				hIoCompletionPort;
+	int				maxIOCPThreads;
+	HANDLE				hIOCPThreads[MAX_IOCPTHREADS];
+	DWORD				dwIOCPThreadIds[MAX_IOCPTHREADS];
 
 	/*
 	 * Debugging.
@@ -1127,23 +1124,12 @@ fill_recv(isc_socket_t *sock, isc_socketevent_t *dev) {
 			sock->recvbuf.from_addr_len);
 		if (isc_sockaddr_getport(&dev->address) == 0) {
 			if (isc_log_wouldlog(isc_lctx, IOEVENT_LEVEL)) {
-				socket_log(__LINE__, sock, &dev->address,
-					   IOEVENT,
+				socket_log(__LINE__, sock, &dev->address, IOEVENT,
 					   "dropping source port zero packet");
 			}
 			sock->recvbuf.remaining = 0;
 			return;
 		}
-		/*
-		 * Simulate a firewall blocking UDP responses bigger than
-		 * 'maxudp' bytes.
-		 */
-		if (sock->manager->maxudp != 0 &&
-		    sock->recvbuf.remaining > sock->manager->maxudp)
-		{
-			sock->recvbuf.remaining = 0;
-			return;
-		}
 	} else if (sock->type == isc_sockettype_tcp) {
 		dev->address = sock->address;
 	}
@@ -1252,18 +1238,6 @@ startio_send(isc_socket_t *sock, isc_socketevent_t *dev, int *nbytes,
 	int status;
 	struct msghdr *mh;
 
-	/*
-	 * Simulate a firewall blocking UDP responses bigger than
-	 * 'maxudp' bytes.
-	 */
-	if (sock->type == isc_sockettype_udp &&
-	    sock->manager->maxudp != 0 &&
-	    dev->region.length - dev->n > sock->manager->maxudp)
-	{
-		*nbytes = dev->region.length - dev->n;
-		return (DOIO_SUCCESS);
-	}
-
 	lpo = (IoCompletionInfo *)HeapAlloc(hHeapHandle,
 					    HEAP_ZERO_MEMORY,
 					    sizeof(IoCompletionInfo));
@@ -1327,8 +1301,7 @@ use_min_mtu(isc_socket_t *sock) {
 
 static isc_result_t
 allocate_socket(isc_socketmgr_t *manager, isc_sockettype_t type,
-		isc_socket_t **socketp)
-{
+		isc_socket_t **socketp) {
 	isc_socket_t *sock;
 	isc_result_t result;
 
@@ -1388,11 +1361,10 @@ allocate_socket(isc_socketmgr_t *manager, isc_sockettype_t type,
 	return (ISC_R_SUCCESS);
 
  error:
-	if (sock->recvbuf.base != NULL) {
-		isc_mem_put(manager->mctx, sock->recvbuf.base,
-			    sock->recvbuf.len);
-	}
+	if (sock->recvbuf.base != NULL)
+		isc_mem_put(manager->mctx, sock->recvbuf.base, sock->recvbuf.len);
 	isc_mem_put(manager->mctx, sock, sizeof(*sock));
+
 	return (result);
 }
 
@@ -2123,11 +2095,9 @@ internal_recv(isc_socket_t *sock, int nbytes)
 		   "internal_recv: %d bytes received", nbytes);
 
 	/*
-	 * If we got here, the I/O operation succeeded.  However, we might
-	 * still have removed this event from our notification list (or never
-	 * placed it on it due to immediate completion.)
-	 * Handle the reference counting here, and handle the cancellation
-	 * event just after.
+	 * If we got here, the I/O operation succeeded.  However, we might still have removed this
+	 * event from our notification list (or never placed it on it due to immediate completion.)
+	 * Handle the reference counting here, and handle the cancellation event just after.
 	 */
 	INSIST(sock->pending_iocp > 0);
 	sock->pending_iocp--;
@@ -2135,15 +2105,13 @@ internal_recv(isc_socket_t *sock, int nbytes)
 	sock->pending_recv--;
 
 	/*
-	 * The only way we could have gotten here is that our I/O has
-	 * successfully completed. Update our pointers, and move on.
-	 *  The only odd case here is that we might not have received
-	 * enough data on a TCP stream to satisfy the minimum requirements.
-	 * If this is the case, we will re-issue the recv() call for what
-	 * we need.
+	 * The only way we could have gotten here is that our I/O has successfully completed.
+	 * Update our pointers, and move on.  The only odd case here is that we might not
+	 * have received enough data on a TCP stream to satisfy the minimum requirements.  If
+	 * this is the case, we will re-issue the recv() call for what we need.
 	 *
-	 * We do check for a recv() of 0 bytes on a TCP stream.  This
-	 * means the remote end has closed.
+	 * We do check for a recv() of 0 bytes on a TCP stream.  This means the remote end
+	 * has closed.
 	 */
 	if (nbytes == 0 && sock->type == isc_sockettype_tcp) {
 		send_recvdone_abort(sock, ISC_R_EOF);
@@ -2320,6 +2288,7 @@ restart_accept(isc_socket_t *parent, IoCompletionInfo *lpo)
 static isc_threadresult_t WINAPI
 SocketIoThread(LPVOID ThreadContext) {
 	isc_socketmgr_t *manager = ThreadContext;
+	BOOL bSuccess = FALSE;
 	DWORD nbytes;
 	IoCompletionInfo *lpo = NULL;
 	isc_socket_t *sock = NULL;
@@ -2349,8 +2318,6 @@ SocketIoThread(LPVOID ThreadContext) {
 	 * Loop forever waiting on I/O Completions and then processing them
 	 */
 	while (TRUE) {
-		BOOL bSuccess;
-
 		wait_again:
 		bSuccess = GetQueuedCompletionStatus(manager->hIoCompletionPort,
 						     &nbytes,
@@ -2508,6 +2475,7 @@ isc_socketmgr_create2(isc_mem_t *mctx, isc_socketmgr_t **managerp,
 		      unsigned int maxsocks, int nthreads)
 {
 	isc_socketmgr_t *manager;
+	isc_result_t result;
 
 	REQUIRE(managerp != NULL && *managerp == NULL);
 
@@ -2538,7 +2506,6 @@ isc_socketmgr_create2(isc_mem_t *mctx, isc_socketmgr_t **managerp,
 	manager->bShutdown = false;
 	manager->totalSockets = 0;
 	manager->iocp_total = 0;
-	manager->maxudp = 0;
 
 	*managerp = manager;
 
@@ -3508,7 +3475,6 @@ isc_socket_cancel(isc_socket_t *sock, isc_task_t *task, unsigned int how) {
 		_set_state(sock, SOCK_CLOSED);
 	}
 	how &= ~ISC_SOCKCANCEL_CONNECT;
-	UNUSED(how);
 
 	maybe_free_socket(&sock, __LINE__);
 }
@@ -3919,10 +3885,9 @@ isc_socketmgr_createinctx(isc_mem_t *mctx, isc_appctx_t *actx,
 	return (result);
 }
 
+/* Not implemented for win32 */
 void
-isc_socketmgr_maxudp(isc_socketmgr_t *manager, unsigned int maxudp) {
-
-	REQUIRE(VALID_MANAGER(manager));
-
-	manager->maxudp = maxudp;
+isc_socketmgr_maxudp(isc_socketmgr_t *manager, int maxudp) {
+	UNUSED(manager);
+	UNUSED(maxudp);
 }
